betty.wikipedia package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.wikipedia package

## Submodules

- betty.wikipedia.copyright_notice module
  - `WikipediaContributors`
    - `WikipediaContributors.__init__()`
    - `WikipediaContributors.new()`
    - `WikipediaContributors.new_for_app()`
    - `WikipediaContributors.summary`
    - `WikipediaContributors.text`
    - `WikipediaContributors.url`

## Module contents

Fetch information from Wikipedia.

final class betty.wikipedia.Image

  Bases: `object`

  An image from Wikimedia Commons.

  __init__(path: Path, media_type: MediaType, title: str, wikimedia_commons_url: str, name: str) → None
  media_type: MediaType
  name: str
  path: Path
  title: str
  wikimedia_commons_url: str

exception betty.wikipedia.NotAPageError

  Bases: `ValueError`

  Raised when a URL does not point to a Wikipedia page.

final class betty.wikipedia.Summary

  Bases: `object`

  A Wikipedia page summary.

  __init__(locale: str, name: str, title: str, content: str) → None
  content: str
  locale: str
  name: str
  title: str
  property url: str

    The URL to the web page.